==> jc-1.4.0.tar.gz: java/text/ParseException.h <==
// public class java.text.ParseException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7b4c2fb9a2b326cf java_text_ParseException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_text_ParseException_H_
#define _JC_java_text_ParseException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_ParseException$sub_refs	_jc_java_text_ParseException$sub_refs;
typedef struct _jc_java_text_ParseException$sub_nonrefs	_jc_java_text_ParseException$sub_nonrefs;
typedef struct _jc_java_text_ParseException$refs	_jc_java_text_ParseException$refs;
typedef struct _jc_java_text_ParseException$nonrefs	_jc_java_text_ParseException$nonrefs;
typedef struct _jc_java_text_ParseException$object	_jc_java_text_ParseException$object;

typedef struct _jc_java_text_ParseException$fields_struct	_jc_java_text_ParseException$fields_struct;
typedef const struct _jc_java_text_ParseException$vmethods	_jc_java_text_ParseException$vmethods;
typedef const struct _jc_java_text_ParseException$vtable	_jc_java_text_ParseException$vtable;
typedef const struct _jc_java_text_ParseException$vtype	_jc_java_text_ParseException$vtype;

// Class fields structure
struct _jc_java_text_ParseException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_text_ParseException$fields_struct _jc_java_text_ParseException$class_fields;

// Constructors
extern void _jc_java_text_ParseException$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_text_ParseException$object *, struct _jc_java_lang_String$object *, jint);

// Virtual methods
extern jint _jc_java_text_ParseException$method$getErrorOffset$8d6ffac81854f072(_jc_env *, struct _jc_java_text_ParseException$object *);

// Virtual method descriptors
extern _jc_method _jc_java_text_ParseException$method_info$getErrorOffset$8d6ffac81854f072;

// Virtual methods structure
struct _jc_java_text_ParseException$vmethods {
	jint	(*getErrorOffset$8d6ffac81854f072)(_jc_env *, struct _jc_java_text_ParseException$object *);
};

// Vtable
struct _jc_java_text_ParseException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_text_ParseException$vmethods	java_text_ParseException;
};

// Vtype
struct _jc_java_text_ParseException$vtype {
	_jc_type			type;
	_jc_java_text_ParseException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_ParseException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_ParseException$refs {
    _jc_java_text_ParseException$sub_refs	java_text_ParseException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_ParseException$sub_nonrefs {
	jint	errorOffset;
};

// Non-reference instance fields (object)
struct _jc_java_text_ParseException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_text_ParseException$sub_nonrefs	java_text_ParseException;
};

// Object instance structure
struct _jc_java_text_ParseException$object {
	_jc_java_text_ParseException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_ParseException$vtype	*vtype;
	_jc_java_text_ParseException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_ParseException$vtype _jc_java_text_ParseException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_ParseException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_ParseException$class_object;

#endif	/* _JC_java_text_ParseException_H_ */

==> jc-1.4.6.tar.gz: java/text/ParseException.h <==
// public class java.text.ParseException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class 7b4c2fb9a2b326cf java_text_ParseException

// header file dependencies
// @dep_header java_lang_Exception

#include "java/lang/Exception.h"

#ifndef _JC_java_text_ParseException_H_
#define _JC_java_text_ParseException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_text_ParseException$sub_refs	_jc_java_text_ParseException$sub_refs;
typedef struct _jc_java_text_ParseException$sub_nonrefs	_jc_java_text_ParseException$sub_nonrefs;
typedef struct _jc_java_text_ParseException$refs	_jc_java_text_ParseException$refs;
typedef struct _jc_java_text_ParseException$nonrefs	_jc_java_text_ParseException$nonrefs;
typedef struct _jc_java_text_ParseException$object	_jc_java_text_ParseException$object;

typedef struct _jc_java_text_ParseException$fields_struct	_jc_java_text_ParseException$fields_struct;
typedef const struct _jc_java_text_ParseException$vmethods	_jc_java_text_ParseException$vmethods;
typedef const struct _jc_java_text_ParseException$vtable	_jc_java_text_ParseException$vtable;
typedef const struct _jc_java_text_ParseException$vtype	_jc_java_text_ParseException$vtype;

// Class fields structure
struct _jc_java_text_ParseException$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_java_text_ParseException$fields_struct _jc_java_text_ParseException$class_fields;

// Constructors
extern void _jc_java_text_ParseException$method$_init$8b03e78e1eb3b29e(_jc_env *, struct _jc_java_text_ParseException$object *, struct _jc_java_lang_String$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern jint _jc_java_text_ParseException$method$getErrorOffset$8d6ffac81854f072(_jc_env *, struct _jc_java_text_ParseException$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_text_ParseException$method_info$getErrorOffset$8d6ffac81854f072;

// Virtual methods structure
struct _jc_java_text_ParseException$vmethods {
	jint	(*getErrorOffset$8d6ffac81854f072)(_jc_env *, struct _jc_java_text_ParseException$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_text_ParseException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_text_ParseException$vmethods	java_text_ParseException;
};

// Vtype
struct _jc_java_text_ParseException$vtype {
	_jc_type			type;
	_jc_java_text_ParseException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_text_ParseException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_text_ParseException$refs {
    _jc_java_text_ParseException$sub_refs	java_text_ParseException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_text_ParseException$sub_nonrefs {
	jint	errorOffset;
};

// Non-reference instance fields (object)
struct _jc_java_text_ParseException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_text_ParseException$sub_nonrefs	java_text_ParseException;
};

// Object instance structure
struct _jc_java_text_ParseException$object {
	_jc_java_text_ParseException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_text_ParseException$vtype	*vtype;
	_jc_java_text_ParseException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_text_ParseException$vtype _jc_java_text_ParseException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_text_ParseException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_text_ParseException$class_object;

#endif	/* _JC_java_text_ParseException_H_ */
